==> ogre_1.7.4+dfsg1.orig.tar.xz: ogre-1.7.4+dfsg1/PlugIns/CgProgramManager/include/OgreCgPrerequisites.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2011 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#ifndef __CgPrerequisites_H__
#define __CgPrerequisites_H__

#include "OgreException.h"
#include <Cg/cg.h>


namespace Ogre {

    /** Utility function, checks Cg for errors, throw exception if detected.
    @param ogreMethod Ogre method name, as Class::method
    @param errorTextPrefix The text to prefix the Cg error text with
    */
    void checkForCgError(const String& ogreMethod, const String& errorTextPrefix, CGcontext context);


#if (OGRE_PLATFORM == OGRE_PLATFORM_WIN32) && !defined(__MINGW32__) && !defined(OGRE_STATIC_LIB)
#	ifdef OGRE_CGPLUGIN_EXPORTS
#		define _OgreCgPluginExport __declspec(dllexport)
#	else
#       if defined( __MINGW32__ )
#           define _OgreCgPluginExport
#       else
#    		define _OgreCgPluginExport __declspec(dllimport)
#       endif
#   endif
#elif defined ( OGRE_GCC_VISIBILITY )
#   define _OgreCgPluginExport  __attribute__ ((visibility("default")))
#else
#	define _OgreCgPluginExport
#endif	// OGRE_WIN32

}

#endif

==> ogre-1.9_1.9.0+dfsg1.orig.tar.xz: ogre-1.9.0/PlugIns/CgProgramManager/include/OgreCgPrerequisites.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2013 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#ifndef __CgPrerequisites_H__
#define __CgPrerequisites_H__

#include "OgreException.h"
#include <Cg/cg.h>


namespace Ogre {

    /** Utility function, checks Cg for errors, throw exception if detected.
    @param ogreMethod Ogre method name, as Class::method
    @param errorTextPrefix The text to prefix the Cg error text with
    */
    void checkForCgError(const String& ogreMethod, const String& errorTextPrefix, CGcontext context);


#if (OGRE_PLATFORM == OGRE_PLATFORM_WIN32 || OGRE_PLATFORM == OGRE_PLATFORM_WINRT) && !defined(__MINGW32__) && !defined(OGRE_STATIC_LIB)
#	ifdef OGRE_CGPLUGIN_EXPORTS
#		define _OgreCgPluginExport __declspec(dllexport)
#	else
#       if defined( __MINGW32__ )
#           define _OgreCgPluginExport
#       else
#    		define _OgreCgPluginExport __declspec(dllimport)
#       endif
#   endif
#elif defined ( OGRE_GCC_VISIBILITY )
#   define _OgreCgPluginExport  __attribute__ ((visibility("default")))
#else
#	define _OgreCgPluginExport
#endif	// OGRE_WIN32

}

#endif
